@@ -286,7 +286,7 @@ cluster_plot <- function(object, N_clusters = NULL, time_points = NULL, units_na
      plot_gcp            <- subset(dat_gcp, dat_gcp[,eval(units_name)] %in% plot_st)    
      ## compose plot
      p.t          		= ggplot(data=plot_gcp,aes(x=time, y = fit) )
-     l				= geom_line(aes_string(group = eval(units_name)),size = 1.2,
+     l				= geom_line(aes_string(group = eval(units_name)),linewidth = 1.2,
                               alpha = 0.6, colour="#FF9999")
      l.2				= geom_point(data=plot_gca,aes_string(group = eval(units_name)),size=3,shape=1,
                          colour="black") ## Add the data
