@@ -4,8 +4,8 @@
 #' \tabular{ll}{
 #' Package: \tab growfunctions\cr
 #' Type: \tab Package\cr
-#' Version: \tab 0.16\cr
-#' Date: \tab 2023-12-08\cr
+#' Version: \tab 0.17\cr
+#' Date: \tab 2025-11-14\cr
 #' License: \tab GPL (>= 3) \cr
 #' LazyLoad: \tab yes\cr
 #' }
@@ -241,7 +241,7 @@
 #'
 #' @name growfunctions-package
 #' @aliases growfunctions package-growfunctions
-#' @docType package
+"_PACKAGE"
 #' @author Terrance Savitsky \email{tds151@gmail.com} 
 #' @references
 #'     Terrance D. Savitsky (2016) Bayesian Nonparametric Mixture Estimation for Time-Indexed 
